@@ -8,7 +8,7 @@ let next_atom = ref 1
 let atom_hash : (trm,int) Hashtbl.t = Hashtbl.create 1000
 let atom_hash_rev : (int,trm) Hashtbl.t = Hashtbl.create 1000
 
-let new_atom_action = ref (fun m a -> ())
+let new_atom_actions = ref []
 
 let max_atom () = (!next_atom) - 1
 
@@ -21,7 +21,7 @@ let new_atom m =
   if (!verbosity > 4) then
     if (!verbosity > 8) then Printf.printf "Atom %d: %s\n" a (trm_str m)
     else (Printf.printf "Atom %d\n" a);
-  !new_atom_action m a;
+  List.iter (fun f -> f m a) !new_atom_actions;
   a
 
 let get_atom m =
