@@ -5,7 +5,7 @@ type literal = int
 
 val max_atom : unit -> atom
 
-val new_atom_action : (Syntax.trm -> atom -> unit) ref
+val new_atom_actions : (Syntax.trm -> atom -> unit) list ref
 
 val atom_to_trm : atom -> trm
 
