@@ -300,6 +300,7 @@ let printf_fs_file s b =
 let read_e_core eout =
   let pcore = ref [] in
   let fcore = ref [] in
+  let elines = ref [] in
   try
     while true do
       match input_line eout with
@@ -311,6 +312,7 @@ let read_e_core eout =
 	    | "# SZS output end CNFRefutation" -> raise Exit
 	    | l ->
 		if !verbosity > 40 then (Printf.printf "eref: %s\n" l; flush stdout);
+		elines := l::!elines;
 		let n = String.length l in
 		let i = ref (n-1) in
 		let a = ref 0 in
@@ -353,7 +355,7 @@ let read_e_core eout =
     done;
     raise Exit (*** unreachable, raise here for ocaml type checking ***)
   with Exit ->
-    (!pcore,!fcore)
+    (!pcore,!fcore,List.rev !elines)
 
 let whitespace_p c = Char.code c <= 32
 
@@ -752,7 +754,7 @@ and construct_refutation_with_e_new nw todecompose foralls foposlits foneglits f
 	  | Ap(Ap(Eq(a),_),_) -> construct_refutation_with_e_new nwr todecompose foralls foposlits foneglits (ncons (get_literal s,s) foposeqns) fonegeqns
 	  | _ -> construct_refutation_with_e_new nwr todecompose foralls (ncons (get_literal s,s) foposlits) foneglits foposeqns fonegeqns
 
-let construct_refutation_with_e (pcore,fcore) =
+let construct_refutation_with_e (pcore,fcore,elines) =
   let todecompose = ref [] in
   let foralls = ref [] in
   let foposlits = ref [] in
@@ -792,13 +794,13 @@ let call_e b =
       let foffile = open_out foffilename in
       printf_fof_file foffile b;
       close_out foffile;
-      Printf.printf "./E/PROVER/eprover -s %s --cpu-limit=%d --tptp3-in%s < %s\n" (if get_bool_flag "E_AUTOSCHEDULE" then "--auto-schedule" else "--auto") etimeoutnow (if mkprooftermp() then " --proof-object" else "") foffilename;
+      Printf.printf "./E/PROVER/eprover -s %s --cpu-limit=%d --tptp3-in%s --tstp-out < %s\n" (if get_bool_flag "E_AUTOSCHEDULE" then "--auto-schedule" else "--auto") etimeoutnow (if mkprooftermp() then " --proof-object" else "") foffilename;
       Unix.sleep 1; (*** sleep for a second so the names will be unique ***)
     end;
   if (etimeoutnow > 0) then
     begin
       if (!verbosity > 4) then Printf.printf "Calling E for %d seconds.\n" etimeoutnow;
-      let (myout,myin,myerr) = Unix.open_process_full ((!Config.eprover) ^ " -s " ^ (if get_bool_flag "E_AUTOSCHEDULE" then "--auto-schedule" else "--auto") ^ " --cpu-limit=" ^ (string_of_int etimeoutnow) ^ "  --tptp3-in" ^ (if mkprooftermp() then " --proof-object" else "")) [| |] in
+      let (myout,myin,myerr) = Unix.open_process_full ((!Config.eprover) ^ " -s " ^ (if get_bool_flag "E_AUTOSCHEDULE" then "--auto-schedule" else "--auto") ^ " --cpu-limit=" ^ (string_of_int etimeoutnow) ^ "  --tptp3-in" ^ (if mkprooftermp() then " --tstp-out --proof-object" else "")) [| |] in
       printf_fof_file myin b;
       close_out myin;
       if (!verbosity > 4) then (Printf.printf "About to read result from eprover\n"; flush stdout);
@@ -819,10 +821,10 @@ let call_e b =
 		    ignore(Unix.close_process_full(myout,myin,myerr));
 		    raise (Unsatisfiable None)
 		| Some(TSTP) ->
-                    let (pcore,fcore) = read_e_core myout in
+                    let (pcore,fcore,elines) = read_e_core myout in
 		    ignore(Unix.close_process_full(myout,myin,myerr));
 		    let cri = !clause_ruleinfo in
-		    raise (Unsatisfiable(Some(Eprover(List.map (fun z -> Hashtbl.find propmatrixh z) pcore,Hashtbl.find cri,fcore))))
+		    raise (Unsatisfiable(Some(Eprover(List.map (fun z -> Hashtbl.find propmatrixh z) pcore,Hashtbl.find cri,fcore,elines))))
 		| Some(ptk) ->
 		    enable_pattern_clauses := false; (*** since we aren't doing general search anymore, turn off pattern clauses ***)
                     let ecore = read_e_core myout in
@@ -849,7 +851,7 @@ let new_possible_fo_formula m a =
 let setup_eprover () =
   if get_bool_flag "USE_E" then
     (if Sys.file_exists !Config.eprover
-    then Atom.new_atom_action := new_possible_fo_formula
+    then Atom.new_atom_actions := new_possible_fo_formula::!Atom.new_atom_actions
     else print_endline "Warning: eprover not found!");
   eeqoequiv := get_bool_flag "E_EQO_EQUIV";
   eproverperiod := get_int_flag "E_PERIOD";
