@@ -18,12 +18,11 @@ let minisat_search_period () =
   else
     true
 
-
 let minisat_result () =
   if (!minisatsearchperiod > 1) then
     begin
       let r = minisat_search () in
-      if (not r) then raise (Unsatisfiable None)
+      if (not r) then raise (Unsatisfiable None);
     end;
   raise Satisfiable
 
