@@ -335,7 +335,7 @@ let print_hocore c r =
 	Printf.printf "hocore_1 a END\n";
       end;
     match r with
-    | Eprover(pcore,cr,fcore) ->
+    | Eprover(pcore,cr,fcore,elines) ->
 	begin
 	  Printf.printf "Eprover\n propositional part:";
 	  List.iter
@@ -375,6 +375,7 @@ let print_hocore c r =
 		    with
 		      Not_found -> ()
 		  end
+	      | MizarSoftTypingRule(ax,l,info) -> report_name ("ST:" ^ ax)
 	      |	ri ->
 		  begin
 		    if (!verbosity > 50) then Printf.printf "cr found it has rule info %s\n" (ruleinfo_str ri);
@@ -509,7 +510,7 @@ let print_pfinfo c r =
 	Printf.printf "pfinfo_1 a END\n";
       end;
     match r with
-    | Eprover(pcore,cr,fcore) ->
+    | Eprover(pcore,cr,fcore,elines) ->
 	begin
 	  Printf.printf "Eprover\n propositional part:";
 	  List.iter
@@ -704,7 +705,7 @@ let print_pfuseful c r o =
   in
   let rec pfuseful_1 c r a =
     match r with
-    | Eprover(pcore,cr,fcore) -> (*** questionable, but ignore fcore for now ***)
+    | Eprover(pcore,cr,fcore,elines) -> (*** questionable, but ignore fcore for now ***)
 	List.iter
 	  (fun c0 ->
 	    try
@@ -1066,7 +1067,7 @@ let print_pfformdeps c r o =
   in
   let rec pfformdeps_1 c r a =
     match r with
-    | Eprover(pcore,cr,fcore) -> List.iter (handle_clause true cr) pcore (*** questionable, but ignore fcore for now ***)
+    | Eprover(pcore,cr,fcore,elines) -> List.iter (handle_clause true cr) pcore (*** questionable, but ignore fcore for now ***)
     | SearchR(cl,cr) -> List.iter (handle_clause true cr) cl
     | AssumptionConflictR(_) -> (*** There must be a formula (m,name) on a such that (~m,name2) is on a. Otherwise, there's a bug. ***)
 	let rec find_conflict a =
