@@ -26,6 +26,8 @@ type ruleinfo =
   | Known of literal * string * stp list
  (*** Delta Rule (expansion of some defns) ***)
   | DeltaRule
+      (*** Mizar Soft Typing ***)
+  | MizarSoftTypingRule of string * literal * string
 
 type refut =
     NegImpR of trm * trm * refut
@@ -39,7 +41,7 @@ type refut =
   | SearchR of clause list * (clause -> ruleinfo)
   | AssumptionConflictR of int
  (*** Eprover ***)
-  | Eprover of clause list * (clause -> ruleinfo) * int list
+  | Eprover of clause list * (clause -> ruleinfo) * int list * string list
 
 (*** For printing a ruleinfo - helpful for debugging. - Chad, Oct 2010 ***)
 let ruleinfo_str s =
@@ -53,6 +55,7 @@ let ruleinfo_str s =
   | ChoiceRule(eps,pred) -> "ChoiceRule(" ^ (trm_str eps) ^ "," ^ (trm_str pred) ^ ")"
   | Known(l,cname,al) -> "Known(" ^ (string_of_int l) ^ "," ^ cname ^ ")"
   | DeltaRule -> "DeltaRule"
+  | MizarSoftTypingRule(ax,l,info) -> "MizarSoftTypingRule(\"" ^ ax ^ "\"," ^ (string_of_int l) ^ ",\"" ^ info ^ "\")"
 
 (*** For printing the refutation - helpful for debugging. - Chad, Oct 2010 ***)
 let rec print_refut r =
@@ -95,8 +98,10 @@ let rec print_refut r =
 	  with Not_found -> Printf.printf "no associated rule\n"
 	)
 	cl
-  | Eprover(pcore,cr,fcore) ->
-      Printf.printf "Eprover\n propositional part:";
+  | Eprover(pcore,cr,fcore,elines) ->
+      Printf.printf "Eprover\n";
+      List.iter (fun l -> Printf.printf "%s\n" l) elines;
+      Printf.printf " propositional part:";
       List.iter
 	(fun c ->
 	  Printf.printf "%s\n" (String.concat " " (List.map string_of_int c));
@@ -129,6 +134,7 @@ let rec consts_of_ruleinfo acc : ruleinfo -> ctx = function
   | MatingRule (_, _)
   | Known (_, _, _) -> acc
   | DeltaRule -> acc
+  | MizarSoftTypingRule(_,_,_) -> acc
 
 let fold_clause f =
   List.fold_right (fun z acc -> f acc (Atom.atom_to_trm (abs z)))
@@ -171,7 +177,7 @@ let rec consts_of_refut acc : refut -> ctx = function
   | NegReflR(_)
   | AssumptionConflictR(_) -> acc
   | SearchR (cl, cr) -> fold_searchr consts_of_trm consts_of_ruleinfo cl cr acc
-  | Eprover(pcore,cr,fcore) -> fold_searchr consts_of_trm consts_of_ruleinfo pcore cr acc (*** ignoring fcore, questionable ***)
+  | Eprover(pcore,cr,fcore,elines) -> fold_searchr consts_of_trm consts_of_ruleinfo pcore cr acc (*** ignoring fcore, questionable ***)
 
 (*List the base types that are referenced in a rule-info.
   NOTE the resulting list doesn't contain duplicate elements.*)
@@ -193,6 +199,7 @@ let rec base_types_of_ruleinfo acc : ruleinfo -> string list = function
   | ConfrontationRule (_, _)
   | MatingRule (_, _) -> acc
   | DeltaRule -> acc
+  | MizarSoftTypingRule(_,_,_) -> acc
 
 (*List the base types that are referenced in a refutation.
   NOTE the resulting list doesn't contain duplicate elements.*)
@@ -222,7 +229,7 @@ let rec base_types_of_refut acc : refut -> string list = function
   | NegReflR(_)
   | AssumptionConflictR(_) -> acc
   | SearchR (cl, cr) -> fold_searchr base_types_of_trm base_types_of_ruleinfo cl cr acc
-  | Eprover(pcore,cr,fcore) -> fold_searchr base_types_of_trm base_types_of_ruleinfo pcore cr acc (*** ignoring fcore; questionable ***)
+  | Eprover(pcore,cr,fcore,elines) -> fold_searchr base_types_of_trm base_types_of_ruleinfo pcore cr acc (*** ignoring fcore; questionable ***)
 
 type refutsiginfo = {
     basetypes : (string,unit) Hashtbl.t;
@@ -265,6 +272,7 @@ let refutsiginfo_of_ruleinfo {basetypes;consttypes;eigendefs;propreferenced} : r
   | MatingRule (_, _)
   | Known (_, _, _) -> ()
   | DeltaRule -> ()
+  | MizarSoftTypingRule(_,_,_) -> ()
     
 let rec refutsiginfo_of_refut {basetypes;consttypes;eigendefs;propreferenced} : refut -> unit = function
     NegImpR (t1, t2, r)
@@ -310,7 +318,7 @@ let rec refutsiginfo_of_refut {basetypes;consttypes;eigendefs;propreferenced} :
 	    refutsiginfo_of_ruleinfo {basetypes;consttypes;eigendefs;propreferenced} (cr c)
 	  with Not_found -> ())
 	cl
-  | Eprover(pcore,cr,fcore) ->
+  | Eprover(pcore,cr,fcore,elines) ->
       List.iter
 	(fun c ->
 	  List.iter
