@@ -26,6 +26,8 @@ type ruleinfo =
   | Known of literal * string * stp list
  (*** Delta Rule (expansion of some defns) ***)
   | DeltaRule
+      (*** Mizar Soft Typing ***)
+  | MizarSoftTypingRule of string * literal * string
 
 type refut =
     NegImpR of trm * trm * refut
@@ -39,7 +41,7 @@ type refut =
   | SearchR of clause list * (clause -> ruleinfo)
   | AssumptionConflictR of int
  (*** Eprover ***)
-  | Eprover of clause list * (clause -> ruleinfo) * int list
+  | Eprover of clause list * (clause -> ruleinfo) * int list * string list
 
 val ruleinfo_str : ruleinfo -> string
 
