@@ -419,7 +419,7 @@ let set_timeouts s =
 
 let auto_schedule () =
   if (!nontheorem) then "schedule_nontheorem"
-  else "schedule_3_1"
+  else "schedule_3_3"
 
 let get_schedule = function
   [] -> load_schedule (auto_schedule ())
@@ -460,6 +460,10 @@ let run_slave final s m =
   output_value myin !is_of_names;
   output_value myin !all_of_names;
   output_value myin !probsig;
+  output_value myin !mizar_symbol_order_pred;
+  output_value myin !mizar_name_tp;
+  output_value myin !mizar_pattern_list;
+  output_value myin !typingaxiomslist;
   close_out myin;
   try
     while true do
@@ -478,9 +482,11 @@ let run_slave final s m =
 	  end
 
 let run_mode m s1 =
-  match s1 with
-  | Some(s1) -> run_slave false (Some(s1)) m
-  | None -> run_slave true None m
+  try
+    match s1 with
+    | Some(s1) -> run_slave false (Some(s1)) m
+    | None -> run_slave true None m
+  with IncompleteSatisfiable -> ()
 
 (*** total time of schedule ***)
 let schedule_time = List.fold_left (fun s1 (x,s2) -> (s1 +. s2)) 0.0
@@ -530,6 +536,7 @@ let name_distance_from_conjecture ps =
   List.iter
     (fun z ->
       match z with
+      | ProbSoftTyping(_) -> ()
       | ProbDef(x,_,m,_,_) ->
 	  let cl = List.map (fun (c,_) -> g c) (consts_of_trm [] m) in
 	  defs := (x,m,cl)::!defs
@@ -610,6 +617,7 @@ let sinelike_premsel ps = (*** based on Hoder Voronkov CADE-23 2011 ***)
   List.iter
     (fun z ->
       match z with
+      | ProbSoftTyping(_) -> ()
       | ProbDef(x,_,m,_,_) ->
 	  let cl = List.map (fun (c,_) -> g c) (consts_of_trm [] m) in (*** Note: consts_of_trm does not contain duplicates, which is important for counting here ***)
 	  Hashtbl.add defs x cl
@@ -705,6 +713,7 @@ let sinelike_premsel ps = (*** based on Hoder Voronkov CADE-23 2011 ***)
   List.mapi
     (fun i z ->
       match z with
+      | ProbSoftTyping(_) -> z
       | ProbDef(x,a,m,al,w) -> ProbDef(x,a,m,al,f x i (try float_of_int (Hashtbl.find itemtriggered x) with Not_found -> 1000000.0))
       | ProbAx(x,r,m,al,w) -> ProbAx(x,r,m,al,f x i (try float_of_int (Hashtbl.find itemtriggered x) with Not_found -> 1000000.0))
       | ProbConj(x,m,al,w) -> ProbConj(x,m,al,f x i 0.0))
@@ -725,6 +734,7 @@ let rec run_sine_schedule_3 ps dml endtime schtime =
 	      List.filter
 		(fun z ->
 		  match z with
+		  | ProbSoftTyping(_) -> true
 		  | ProbDef(_,_,_,_,w) -> w <= r
 		  | ProbAx(_,_,_,_,w) -> w <= r
 		  | ProbConj(_,_,_,w) -> w <= r)
@@ -735,6 +745,7 @@ let rec run_sine_schedule_3 ps dml endtime schtime =
 		List.iter
 		  (fun z ->
 		    match z with
+		    | ProbSoftTyping(_) -> ()
 		    | ProbDef(x,_,_,_,_) -> Printf.printf "Including def %s\n" x
 		    | ProbAx(x,_,_,_,_) -> Printf.printf "Including ax %s\n" x
 		    | ProbConj(x,_,_,_) -> Printf.printf "Including conj %s\n" x)
@@ -794,7 +805,21 @@ let run_sine_schedule sineschedule endtime schtime =
   let oldcompletep = !completep in
   enslave ["-i"];
   run_sine_schedule_1 sineschedule endtime schtime
-	
+
+let load_mizar_knowledge c =
+  declare_base_type "$i";
+  let msop : (string, string) Hashtbl.t = input_value c in
+  let mntp : (string,stp) Hashtbl.t = input_value c in
+  let mpl : (string * int * trm list * stp * int list * trm * trm) list = input_value c in
+  let tal : mizartypingaxiom list = input_value c in
+  if get_bool_flag "USE_MIZAR_SOFT_TYPES" then
+    begin
+      completep := false; (*** note incompleteness, so termination does not imply satisfiability ***)
+      if !verbosity > 4 then Printf.printf "init_mizar_knowledge BEGIN\n";
+      init_mizar_knowledge msop mntp mpl tal;
+      if !verbosity > 4 then Printf.printf "init_mizar_knowledge END\n"
+    end
+
 let run_modes modes =
   try
     List.iter load_mode modes;
@@ -818,6 +843,7 @@ let run_modes modes =
 	all_of_names := input_value stdin;
 	List.iter (fun x -> Hashtbl.add all_of_name x ()) !all_of_names;
 	probsig := input_value stdin;
+	load_mizar_knowledge stdin;
 	List.iter init_probitem !probsig
       end
     else
@@ -828,13 +854,18 @@ let run_modes modes =
 	  List.fold_left
 	    (fun v z ->
 	      match z with
+	      | ProbSoftTyping(_) -> v
 	      | ProbDef(_,_,_,_,w) -> v +. w
 	      | ProbAx(_,_,_,_,w) -> v +. w
 	      | ProbConj(_,_,_,w) -> v +. w)
 	    0.0 !probsig
 	in
+	if !verbosity > 4 then Printf.printf "preweightsum %f\n" preweightsum; flush stdout;
 	if preweightsum < 128.0 then (*** the problem is small enough; don't do sine ***)
-	  List.iter init_probitem !probsig
+	  begin
+	    if get_bool_flag "USE_MIZAR_SOFT_TYPES" then init_mizar_knowledge !mizar_symbol_order_pred !mizar_name_tp !mizar_pattern_list !typingaxiomslist;
+	    List.iter init_probitem !probsig
+	  end
 	else
 	  let r = match !sine_depth with Some(r) -> r | None -> 3.0 in
 	  sine_depth := Some(r);
@@ -843,6 +874,7 @@ let run_modes modes =
 	    List.filter
 	      (fun z ->
 		match z with
+		| ProbSoftTyping(_) -> true
 		| ProbDef(_,_,_,_,w) -> w <= r
 		| ProbAx(_,_,_,_,w) -> w <= r
 		| ProbConj(_,_,_,w) -> w <= r)
@@ -853,6 +885,7 @@ let run_modes modes =
 	      List.iter
 		(fun z ->
 		  match z with
+		  | ProbSoftTyping(_) -> ()
 		  | ProbDef(x,_,_,_,_) -> Printf.printf "Including def %s\n" x
 		  | ProbAx(x,_,_,_,_) -> Printf.printf "Including ax %s\n" x
 		  | ProbConj(x,_,_,_) -> Printf.printf "Including conj %s\n" x)
@@ -899,16 +932,21 @@ let search_main () =
 	List.fold_left
 	  (fun v z ->
 	    match z with
+	    | ProbSoftTyping(_) -> v
 	    | ProbDef(_,_,_,_,w) -> v +. w
-	    | ProbAx(_,_,_,_,w) -> v +. w
+	    | ProbAx(ax,_,_,_,w) -> v +. w
 	    | ProbConj(_,_,_,w) -> v +. w)
 	  0.0 !probsig
       in
+      if !verbosity > 4 then Printf.printf "preweightsum %f\n" preweightsum; flush stdout;
       if preweightsum < 128.0 then (*** the problem is small enough to do the default strategy schedule ***)
-	if !timeout = None then
-	  run_schedule_notimeout (get_schedule !schedule_files)
-	else
-	  run_schedule (get_schedule !schedule_files) !endtime
+	begin
+	  if not !completep then enslave ["-i"];
+	  if !timeout = None then
+	    run_schedule_notimeout (get_schedule !schedule_files)
+	  else
+	    run_schedule (get_schedule !schedule_files) !endtime
+	end
       else (*** the problem is large; do premise selection and then call the schedule on slices ***)
 	let sineschedule = get_sine_schedule !schedule_files in
 	run_sine_schedule sineschedule !endtime (List.fold_left (fun s1 (_,_,dml) -> s1 +. (List.fold_left (fun s1 (_,_,s2) -> (s1 +. s2)) 0.0 dml)) 0.0 sineschedule)
