@@ -50,9 +50,6 @@ let pattern_clauses_transitivity_types : (stp,unit) Hashtbl.t = Hashtbl.create 1
 let not_in_prop_model_delay_p : bool ref = ref false (*** Nov 2011 ***)
 let not_in_prop_model_delay : int ref = ref 0        (*** Nov 2011 ***)
 
-
-
-
 let get_literal_fn1 : (trm -> int) ref = ref get_literal
 let get_literal_fn2 : (trm -> int) ref = ref get_literal
 
@@ -131,10 +128,12 @@ let seen_inst_p a m =
   Hashtbl.mem seen_instantiations (a,m)
 
 let see_inst a m =
-  Hashtbl.add seen_instantiations (a,m) ()
+  Hashtbl.add seen_instantiations (a,m) ();
+  if a = Base("$i") then all_mizar_sorts mizst m
 
 let reset_search_1 () =
   reset_search();
+  reset_mizstate mizst;
   Hashtbl.clear seen_instantiations
 
 let rec stp_weight a =
@@ -253,6 +252,7 @@ let instantiation_priority a m =
 let process_instantiation a m =
   begin (*** Process it now -- making it passive ***)
     add_instantiation a m;
+    if (get_bool_flag "USE_MIZAR_SOFT_TYPES") && (a = Base("$i")) then all_mizar_sorts mizst m;
     List.iter
       (fun (lit,p) -> (*** Instantiate known universal predicates ***)
 	if not (filteredp (-lit)) then
@@ -942,6 +942,7 @@ let process_negation mlit m nm =
 	  ()
 	else
 	  begin
+	    if (get_bool_flag "USE_MIZAR_SOFT_TYPES") then assert_mizar_sorts mizst m;
 	    if (decomposable x) then
 	      begin
 		let pmd = get_int_flag "PRE_MATING_DELAY_NEG" in
@@ -1190,6 +1191,7 @@ let process_unprocessed_prop mlit m =
 	      ()
 	    else
 	      begin
+		if (get_bool_flag "USE_MIZAR_SOFT_TYPES") then assert_mizar_sorts mizst m;
 		if (!enable_pattern_clauses && not (!apply_pattern_clauses_early)) then (apply_pattern_clauses mlit m);
 		if (decomposable x) then
 		  begin
@@ -1548,6 +1550,9 @@ let search_1 b1 b2 =
   let _ = minisat_init (!verbosity) in
   if (!verbosity > 3) then print_endline "Initialized minisat";
 
+  (*** Add literals for mizar style typing axioms - Jan 18 2018 ***)
+  List.iter (fun l -> new_assumption_lit l) !mizar_typing_axiom_lits;
+
   (*** Process "conjecture" part first - March 18 2011 ***)
   List.iter (process_and_insert insert_conjecture) b1;
   (*** Process "axiom" part second - March 18 2011 ***)
@@ -1789,6 +1794,12 @@ let search () =
   setup_basetypes ();
   setup_prop_model_delay ();
 
+  begin
+    let (_,_,_,_,_,_,f) = mizst in
+    let dmstl = get_int_flag "DELAY_MIZAR_SOFT_TYPES_NEW_LITS" in
+    f := fun m -> insertWithPriority dmstl (ProcessProp1 m)
+  end;
+
   search_init ();
 
   (*** split branch into conjecture part (b1) and axiom part (b2) ***)
