@@ -7,6 +7,73 @@ open Syntax
 open Config
 open Refut
 
+  (*** BEGIN mizartypeinfo module -- inlined here (Jan 2018) ***)
+type mizartypingaxiom =
+  | MizarTypeHierarchyStrict of string * trm * string list * int * trm list * trm list
+  | MizarTypeHierarchy of string * trm * string list * int * trm list * trm list
+  | MizarFunctionType of string * trm * string list * int * trm list * trm list
+  | MizarTypingGeneric of string * trm * int * trm list * trm list
+  | MizarRedefinition of string * trm * int * trm list * string * trm list * trm
+  | MizarClusterNonempty of string * trm * int * trm list * trm list
+val typingaxiomslist : mizartypingaxiom list ref
+
+val mizar_pattern_table : (string,int * trm list * stp * int list * trm * trm) Hashtbl.t
+val mizar_pattern_list : (string * int * trm list * stp * int list * trm * trm) list ref
+
+val mizar_typing_axiom_lits : int list ref
+
+val mizar_name_tp : (string,stp) Hashtbl.t ref
+val mizar_symbol_order_pred : (string, string) Hashtbl.t ref
+
+val extract_conjuncts : trm -> bool -> trm list
+
+val names_in_mizar_type_assumptions : string list ref
+val mizar_hook_names : string list ref
+
+val mizar_func_types : (string,string * int * int * trm list * trm list) Hashtbl.t
+val mizar_typing : (string,string * int * int * trm * trm list * trm list) Hashtbl.t
+val mizar_typing_gen_forward : (string,string * int * int * trm * trm list * trm list) Hashtbl.t
+val mizar_redef : (string,string * int * int * trm list * trm list * trm) Hashtbl.t
+
+val mizar_type_fact1_p : trm -> int -> trm list -> int * trm list * trm list
+val mizar_type_fact2o_p : int -> trm -> bool
+val mizar_type_fact3o_p : trm -> bool
+val mizar_type_fact4o_p : trm -> bool
+val mizar_type_fact5o_p : trm -> int -> trm list -> int * trm list * string * trm list * trm
+
+val mizar_pattern : trm -> int -> trm list -> string * int * trm list * stp * int list * trm * trm
+
+val pre_head_spine : pretrm -> pretrm list -> pretrm * pretrm list
+    
+exception ElaborationSimpleTypeError of trm * stp * stp
+exception ElaborationPatternArityError of string * int * int
+exception ElaborationFailure of string
+
+type cctables = (trm,unit) Hashtbl.t * (trm,trm) Hashtbl.t * (trm,trm) Hashtbl.t * (trm,trm) Hashtbl.t
+
+val abstract_subterms : int -> trm -> trm -> trm
+
+val mizar_pos_typing_predicates : (string,unit) Hashtbl.t
+val mizar_neg_typing_predicates : (string,unit) Hashtbl.t
+
+type mizstate = (pretrm,trm * stp * ((string * (trm list)) list)) Hashtbl.t * (trm,trm) Hashtbl.t * (trm,trm) Hashtbl.t * (trm,unit) Hashtbl.t * cctables * ((string,unit) Hashtbl.t * bool ref * int ref) * ((trm -> unit) ref)
+      
+val nxtfreshvar : stp -> mizstate -> trm
+
+val union_frees : ((string * (trm list)) list) -> ((string * (trm list)) list) -> ((string * (trm list)) list)
+    
+val mizar_widen : mizstate -> trm -> unit
+
+val mizar_typing_assumed_lits_h : (int,unit) Hashtbl.t
+
+val all_mizar_sorts : mizstate -> trm -> unit
+val assert_mizar_sorts : mizstate -> trm -> unit
+
+val reset_mizstate : mizstate -> unit
+    
+val init_mizar_knowledge : (string, string) Hashtbl.t -> (string,stp) Hashtbl.t -> (string * int * trm list * stp * int list * trm * trm) list -> mizartypingaxiom list -> unit
+  (*** END mizartypeinfo module -- inlined here (Jan 2018) ***)
+
 exception CoqProofTooBig of int
 
 val select_axioms_list : int list ref
@@ -37,10 +104,12 @@ val is_of_name : (string,unit) Hashtbl.t
 val all_of_name : (string,unit) Hashtbl.t
 
 type probitem =
+  | ProbSoftTyping of mizartypingaxiom
   | ProbDef of string * stp * trm * (string * string) list * float
   | ProbAx of string * string * trm * (string * string) list * float
   | ProbConj of string * trm * (string * string) list * float
 val probsig : probitem list ref
+val mizst : mizstate
 val init_probitem : probitem -> unit
 val recognize_hashroots : bool ref
 
