@@ -2211,7 +2211,6 @@ let rec base_types_of_trm acc : trm -> string list = function
     base_types acc stp
   | False | Imp | True | Neg | Or | And | Iff -> acc
 
-
 let fresh_prefix = "__"
 
 let make_fresh_name i = fresh_prefix ^ string_of_int i
@@ -2253,3 +2252,97 @@ let normalize_asc m =
   fold_names (normalize_asc_fun (fun x -> true) (fun i -> "c" ^ string_of_int i)) ([], 0) m
 
 let contains_fresh_names m = let ((_, i), _) = normalize_fresh_asc m in i > 0
+
+(***
+ gives a version with named vars and ~, ->, ! intended to be more readable for the humans.
+ partially based on the printer code for Egal
+ ***)
+let next_var_name a names othernames =
+  let basevarnames = ["x";"y";"z";"w";"u";"v"] in
+  let predvarnames = ["p";"q";"r"] in
+  let funcvarnames = ["f";"g";"h"] in
+  let varnames = if rtp a = Prop then predvarnames else match a with Ar(_,_) -> funcvarnames | _ -> basevarnames in
+  let numvarnames = List.length varnames in
+  let var_name_of j =
+    if j < numvarnames then
+      List.nth varnames j
+    else
+      let k = j / numvarnames in
+      let m = j mod numvarnames in
+      (List.nth varnames m) ^ string_of_int k
+  in
+  let i = ref 0 in
+  let x = ref (var_name_of 0) in
+  try
+    while true do
+      if List.mem !x names || List.mem !x othernames then (incr i; x := var_name_of !i) else raise Exit
+    done;
+    ""
+  with Exit -> !x
+
+let trm_str_nice_paren q (s,p) = if p <= q then s else "(" ^ s ^ ")"
+
+let rec binderp m =
+  match m with
+  | Lam(_,_) -> true
+  | Ap(Forall(_),Lam(_,_)) -> true
+  | _ -> false
+
+let rec trm_str_nice_rec m names othernames =
+  match m with
+    Name(x,_) -> (x,0)
+  | Lam(Ar(a1,a2),DB(0,_)) when (a1 = a2) -> ("#1:" ^ (stp_str a1),0) (*** Church Numeral 1 Printed in a special way. - Chad, Feb 2, 2011 ***)
+  | Lam(Ar(a1,a2),Lam(a3,m)) when a1 = a2 && a1 = a3 && church_num_body m -> ("#" ^ string_of_int (church_num_body_val m) ^ ":" ^ stp_str a1,0) (*** Church Numerals Printed in a special way. - Chad, Feb 2, 2011 ***)
+  | False -> ("False",0)
+  | Imp -> ("imp",0)
+  | Forall(a) -> ("Pi:" ^ (stp_str a),0)
+  | Eq(a) -> ("eq:" ^ (stp_str a),0)
+  | Choice(a) -> ("Sepsilon:" ^ (stp_str a),0)
+  | DB(i,_) ->
+      begin
+	try
+	  let x = List.nth names i in
+	  (x,0)
+	with Failure(_) ->
+	  ("^" ^ (string_of_int (i - List.length names)),0)
+      end
+  | Lam(a,m1) ->
+      let x = next_var_name a names othernames in
+      ("\\" ^ x ^ ":" ^ (stp_str a) ^ "." ^ (trm_str_nice_paren 1010 (trm_str_nice_rec m1 (x::names) othernames)),1)
+  | Ap(Ap(Eq(_),m1),m2) ->
+      if binderp m1 then (*** to properly use 'binderish' I would need a separate 'layout' type; I'll use binderp instead and hope it's OK ***)
+	((trm_str_nice_paren (-1) (trm_str_nice_rec m1 names othernames)) ^ " = " ^ (trm_str_nice_paren 502 (trm_str_nice_rec m2 names othernames)),502)
+      else
+	((trm_str_nice_paren 502 (trm_str_nice_rec m1 names othernames)) ^ " = " ^ (trm_str_nice_paren 502 (trm_str_nice_rec m2 names othernames)),502)
+  | Ap(Ap(Imp,Ap(Ap(Eq(_),m1),m2)),False) ->
+      if binderp m1 then (*** to properly use 'binderish' I would need a separate 'layout' type; I'll use binderp instead and hope it's OK ***)
+	((trm_str_nice_paren (-1) (trm_str_nice_rec m1 names othernames)) ^ " <> " ^ (trm_str_nice_paren 502 (trm_str_nice_rec m2 names othernames)),502)
+      else
+	((trm_str_nice_paren 502 (trm_str_nice_rec m1 names othernames)) ^ " <> " ^ (trm_str_nice_paren 502 (trm_str_nice_rec m2 names othernames)),502)
+  | Ap(Ap(Imp,m1),False) ->
+      ("~" ^ (trm_str_nice_paren 701 (trm_str_nice_rec m1 names othernames)),701)
+  | Ap(Ap(Imp,m1),m2) ->
+      if binderp m1 then (*** to properly use 'binderish' I would need a separate 'layout' type; I'll use binderp instead and hope it's OK ***)
+	((trm_str_nice_paren (-1) (trm_str_nice_rec m1 names othernames)) ^ " -> " ^ (trm_str_nice_paren 801 (trm_str_nice_rec m2 names othernames)),800)
+      else
+	((trm_str_nice_paren 800 (trm_str_nice_rec m1 names othernames)) ^ " -> " ^ (trm_str_nice_paren 801 (trm_str_nice_rec m2 names othernames)),800)
+  | Ap(Forall(a),Lam(_,m1)) ->
+      let x = next_var_name a names othernames in
+      ("!" ^ x ^ ":" ^ (stp_str a) ^ "." ^ (trm_str_nice_paren 1010 (trm_str_nice_rec m1 (x::names) othernames)),1)
+  | Ap(m1,m2) ->
+      if binderp m1 then (*** to properly use 'binderish' I would need a separate 'layout' type; I'll use binderp instead and hope it's OK ***)
+	((trm_str_nice_paren (-1) (trm_str_nice_rec m1 names othernames)) ^ " " ^ (trm_str_nice_paren 0 (trm_str_nice_rec m2 names othernames)),1)
+      else
+	((trm_str_nice_paren 1 (trm_str_nice_rec m1 names othernames)) ^ " " ^ (trm_str_nice_paren 0 (trm_str_nice_rec m2 names othernames)),1)
+(*** If logic has not been normalized away ***)
+  | True -> ("True",0)
+  | Neg -> ("not",0)
+  | Or -> ("or",0)
+  | And -> ("and",0)
+  | Iff -> ("iff",0)
+  | Exists(_) -> ("Sigma",0)
+
+let trm_str_nice m =
+  let nl = List.map (fun (x,_) -> x) (consts_of_trm [] m) in
+  let (s,_) = trm_str_nice_rec m [] nl in
+  s
